import '../uibit.dart';

enum KTextType { normal, title, tab,code }

class KTextStyle extends TextStyle {


  const KTextStyle({double fontSize, Color color, FontWeight fontWeight}) : super(fontSize: fontSize, color: color, fontWeight: fontWeight, decoration: TextDecoration.none);

  static const KTextStyle normal = KTextStyle(fontSize: 14, color: kColor.light0);
  static const KTextStyle lunch = KTextStyle(fontSize: 25, color: kColor.light0, fontWeight: FontWeight.w800);
  static const KTextStyle boardingTitle = KTextStyle(fontSize: 55, color: kColor.light0, fontWeight: FontWeight.w900);
  static const KTextStyle boardingInfo = KTextStyle(fontSize: 25, color: kColor.light8, fontWeight: FontWeight.w800);
  static const KTextStyle selected = KTextStyle(fontSize: 14, color: kColor.light0);

  ///---->

  static const KTextStyle tabBold = KTextStyle(fontSize: 16, color: kColor.light0, fontWeight: FontWeight.w700);
  static const KTextStyle tabNormal = KTextStyle(fontSize: 16, color: kColor.light8, fontWeight: FontWeight.w500);
  static const KTextStyle chipBold = KTextStyle(fontSize: 12, color: kColor.light7, fontWeight: FontWeight.w700);
  static const KTextStyle chipNormal = KTextStyle(fontSize: 12, color: kColor.light6, fontWeight: FontWeight.w500);

  //--//--//
  static const KTextStyle title = KTextStyle(fontSize: 22, color: kColor.light0, fontWeight: FontWeight.w600);
  static const KTextStyle large = KTextStyle(fontSize: 27.5, color: kColor.light0, fontWeight: FontWeight.w400);

  static const KTextStyle light = KTextStyle(fontSize: 14, color: kColor.light0);
  static const KTextStyle bold = KTextStyle(fontSize: 14, color: kColor.light0, fontWeight: FontWeight.w600);
  static const KTextStyle slim = KTextStyle(fontSize: 14, color: kColor.light0);
  static const KTextStyle button = KTextStyle(fontSize: 14, color: kColor.mind, fontWeight: FontWeight.w600);
  static const KTextStyle tab = KTextStyle(fontSize: 14, color: kColor.light0, fontWeight: FontWeight.w600);
  static const KTextStyle list = KTextStyle(fontSize: 14, color: kColor.light0, fontWeight: FontWeight.w600);
}

class KText extends StatefulWidget {
  final KTextType type;
  final String text;
  final bool selected;

  const KText({Key key, this.type, this.text, this.selected}) : super(key: key);

  @override
  _KTextState createState() => _KTextState();
}

class _KTextState extends State<KText> {
  KTextType get type => widget.type ?? KTextType.normal;

  bool get selected => widget.selected ?? false;

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.topLeft,
      padding: _padding(),
      child: Text(
        widget.text ?? "",
        style: _textStyle(),
      ),
    );
  }

  _textStyle() {
    switch (type) {
      case KTextType.normal:
        return selected?KTextStyle.normal:KTextStyle.selected;
      case KTextType.title:
        return KTextStyle.title;
      case KTextType.tab:
        return KTextStyle.tab;
      case KTextType.code:
        return KTextStyle(fontSize: 14,color: kColor.mind);
        break;
    }
  }

  _padding() {
    switch (type) {
      case KTextType.normal:
        return EdgeInsets.all(7.5);
      case KTextType.title:
        return EdgeInsets.all(7.5).copyWith(top: 25, bottom: 15);
      case KTextType.tab:
        return EdgeInsets.all(7.5).copyWith(top: 15, bottom: 15);
      case KTextType.code:
        return EdgeInsets.all(7.5);
        break;
    }
  }
}

class KTextPainter extends CustomPainter {
  final bool selected;
  final KTextType type;

  KTextPainter({this.selected, this.type});

  @override
  void paint(Canvas canvas, Size size) {
    final p = Paint();
    p.style = PaintingStyle.fill;
    p.color = selected ? kColor.mind : kColor.none;
    canvas.drawCircle(Offset(size.width / 2, size.height + 5), 2.5, p);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return oldDelegate != this;
  }
}
