import 'dart:ui';

import 'package:path_parsing/path_parsing.dart';

class PathPrinter extends PathProxy {
  final Path path;
  bool debug = true;

  PathPrinter(this.path);

  List<String> logs = [];

  @override
  void close() {
    logs.add('path.close();');
    print(logs.join(" "));
    path.close();
  }

  @override
  void cubicTo(double x1, double y1, double x2, double y2, double x3, double y3) {
    logs.add('path.cubicTo(${x1.round()}, ${y1.round()}, ${x2.round()}, ${y2.round()}, ${x3.round()}, ${y3.round()});');
    path.cubicTo(x1, y1, x2, y2, x3, y3);
  }

  @override
  void lineTo(double x, double y) {
    logs.add('path.lineTo($x, $y);');
    path.lineTo(x, y);
  }

  @override
  void moveTo(double x, double y) {
    logs.add('path.moveTo($x, $y);');
    path.moveTo(x, y);
  }

  static draw({String data, Path path}) {
    data = data ?? 'M0,0V250H190.5c12.87,0,24.17-7.95,29.37-20.31l.16-.37c11.45-27.17,48.25-27,59.55.19h0A32.64,32.64,0,0,0,309.5,250H500V0Z';
    writeSvgPathDataToPath(data, PathPrinter(path));
  }

  ///
  /// PathPrinter.draw(
  ///      data: "M$w,${h}h0a$r,$r,0,0,0-$r-${r}H${r}A$r,$r,0,0,0,0,${h}H0V0H${w}Z",
  ///      path: path,
  ///    );

  static bottomInnerRadius({double h = 300, double w = 200, double r = 25}) {
    final path = Path();
    path.moveTo(w, h);
    path.lineTo(w, h);
    path.cubicTo(w, h - r, w - r, h - r, w - r, h - r);
    path.lineTo(r, h - r);
    path.cubicTo(r, h - r, 0, h - r, 0, h);
    path.lineTo(0.0, h);
    path.lineTo(0.0, 0.0);
    path.lineTo(w, 0.0);
    path.close();
    return path;
  }
}
