import '../uibit.dart';
import 'package:tinycolor/tinycolor.dart';

class Room extends StatelessWidget {
  final Widget child;
  final int light;
  final AlignmentGeometry begin;
  final AlignmentGeometry end;
  final bool safeArea;

  const Room({Key key, this.child, this.light = 0, this.begin, this.end, this.safeArea}) : super(key: key);

  Widget get finalChild => safeArea == true ? SafeArea(child: child) : child;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        gradient: LinearGradient(
          colors: colors(),
          begin: begin ?? Alignment.topLeft,
          end: end ?? Alignment.bottomRight,
        ),
      ),
      child: Material(
        child: finalChild,
        color: kColor.none,
      ),
    );
  }

  List<Color> colors() {
    int d = light.abs();
    if (light < 0) {
      return [
        TinyColor(kColor.front).darken(d).color,
        TinyColor(kColor.back).darken(d).color,
      ];
    }
    return [
      TinyColor(kColor.front).lighten(d).color,
      TinyColor(kColor.back).lighten(d).color,
    ];
  }
}

class RoomBox extends StatelessWidget {
  final Widget child;
  final double height;

  final int light;

  const RoomBox({Key key, this.child, this.light = 0, this.height}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      height: height,
      alignment: Alignment.center,
      decoration: BoxDecoration(
        color: kColor.light8,
        borderRadius: BorderRadius.circular((height ?? kSize.edgeLarge) / 2),
        boxShadow: kDecoration.boxShadow,
      ),
      padding: kEdge.all,
      child: child,
    );
  }
}
