import 'dart:io';
import 'dart:math';
import '../uibit.dart';

ThemeData get kTheme => ThemeData(brightness: Brightness.dark, applyElevationOverlayColor: true, scaffoldBackgroundColor: Colors.transparent, primaryColor: kColor.front, iconTheme: IconThemeData(color: kColor.light0, size: 37));

// ignore: camel_case_types
class kDecoration {
  
  static const LinearGradient gradient = LinearGradient(
    colors: [kColor.front, kColor.back],
    begin: Alignment.topLeft,
    end: Alignment.bottomRight,
  );

  static var boxShadow=[BoxShadow(color: kColor.mind.withOpacity(.3), offset: Offset(0.0, 8.0), blurRadius: 8.0)];
}

// ignore: camel_case_types
class kEdge {
  static const EdgeInsets all = EdgeInsets.all(kSize.edge);
  static const EdgeInsets left = EdgeInsets.only(left: kSize.edge);
  static const EdgeInsets right = EdgeInsets.only(right: kSize.edge);
  static const EdgeInsets top = EdgeInsets.only(top: kSize.edge);
  static const EdgeInsets bottom = EdgeInsets.only(bottom: kSize.edge);

  static const EdgeInsets allBig = EdgeInsets.all(kSize.edgeBig);
  static const EdgeInsets topBig = EdgeInsets.only(top: kSize.edgeBig);
  static const EdgeInsets title = EdgeInsets.only(top: 25, bottom: 15);
  static const EdgeInsets horizontal = EdgeInsets.symmetric(horizontal: kSize.edge);
  static const EdgeInsets horizontalBig = EdgeInsets.symmetric(horizontal: kSize.edgeBig);
  static const EdgeInsets vertical = EdgeInsets.symmetric(vertical: kSize.edge);
  static const EdgeInsets verticalBig = EdgeInsets.symmetric(vertical: kSize.edgeBig);
  static const EdgeInsets chip = EdgeInsets.only(left: 15, right: 15, top: 7.5, bottom: 7.5);
  static const EdgeInsets head = EdgeInsets.only(left: 15, right: 15, top: 15, bottom: 7.5);
  static const EdgeInsets foot = EdgeInsets.only(left: 15, right: 15, top: 7.5, bottom: 15);
}

// ignore: camel_case_types
class kRadius {
  static const BorderRadius all = BorderRadius.all(Radius.circular(kSize.radius));
  static const BorderRadius radiusSmall = BorderRadius.all(Radius.circular(kSize.radiusSmall));
  static const BorderRadius right = BorderRadius.only(topRight: Radius.circular(kSize.radius), bottomRight: Radius.circular(kSize.radius));
  static const BorderRadius left = BorderRadius.only(topLeft: Radius.circular(kSize.radius), bottomLeft: Radius.circular(kSize.radius));
  static const BorderRadius top = BorderRadius.only(topRight: Radius.circular(kSize.radius), topLeft: Radius.circular(kSize.radius));
  static const BorderRadius bottom = BorderRadius.only(bottomLeft: Radius.circular(kSize.radius), bottomRight: Radius.circular(kSize.radius));

  static BorderRadius only({
    double topLeft = 0.0,
    double topRight = 0.0,
    double bottomLeft = 0.0,
    double bottomRight = 0.0,
  }) {
    return BorderRadius.only(
      topLeft: Radius.circular(topLeft),
      topRight: Radius.circular(topRight),
      bottomLeft: Radius.circular(bottomLeft),
      bottomRight: Radius.circular(bottomRight),
    );
  }

  static radiusTo(double radius) => BorderRadius.all(Radius.circular(radius));
}

// ignore: camel_case_types
class kDuration extends Duration {
  static const Duration ms100 = Duration(milliseconds: 100);
  static const Duration page = Duration(milliseconds: 300);

  static Duration timeout=Duration(seconds: 5);
}

// ignore: camel_case_types
class kSize {
  static const double icon = 25;
  static const double iconSmall = 20;
  static const double iconLarge = 50;

  static const double radius = 25;
  static const double radiusSmall = 15;
  static const double line = 15;
  static const double lineSmall = 7.5;
  static const double edgeSmall = 7.5;
  static const double edge = 10;
  static const double edgeBig = 25;
  static const double edgeLarge = 50;
  static const double minSideWidth = 100;

  static const double slider = 25;

  static double getChildDividend = 1 / 7;

  static double get bottomNavHeight => Platform.isIOS ? 95 : 75;

  static double get kTopPadding => Uikit.mediaQuery.padding.top;

  static double get kBottomPadding => Uikit.mediaQuery.padding.bottom;

  static double get kToolBarHeightWithTopPadding => kToolbarHeight + kTopPadding;

  static double get circleItemExtend => (height - edgeLarge) * getChildDividend;

  static double get circleRadius => (kSize.height - kSize.edgeLarge) * .425 - circleItemExtend / (2 * pi);

  static double get height => Uikit.mediaQuery.size.height;

  static double heighter(double a, [double b]) => height / a * (b ?? 1);

  static double get width => Uikit.mediaQuery.size.width;

  static double get minWidth => width - minSideWidth;

  static double widther(double a, [double b]) => width / a * (b ?? 1);
}

// ignore: camel_case_types
class kColor extends Color  {
  static const Color none = Colors.transparent;

  kColor(int value) : super(value);

  const kColor.light({double opacity = 0.5}) : super.fromRGBO(255, 255, 255, opacity);

  const kColor.dark({double opacity = 0.5}) : super.fromRGBO(0, 0, 0, opacity);

  static const Color front = Color(0xFFC63254);
  static const Color mind = Color(0xFF5F304A);
  static const Color back = Color(0xFF002D40);

  static const Color base = kColor.light();

  static const Color dark1 = kColor.dark(opacity: 0.05);
  static const Color dark2 = kColor.dark(opacity: 0.10);
  static const Color dark3 = kColor.dark(opacity: 0.15);
  static const Color dark4 = kColor.dark(opacity: 0.25);
  static const Color dark5 = kColor.dark(opacity: 0.35);
  static const Color dark6 = kColor.dark(opacity: 0.45);
  static const Color dark7 = kColor.dark(opacity: 0.55);
  static const Color dark8 = kColor.dark(opacity: 0.65);
  static const Color dark9 = kColor.dark(opacity: 0.85);
  static const Color dark0 = kColor.dark(opacity: 1.0);

  static const Color light1 = kColor.light(opacity: 0.05);
  static const Color light2 = kColor.light(opacity: 0.10);
  static const Color light3 = kColor.light(opacity: 0.15);
  static const Color light4 = kColor.light(opacity: 0.25);
  static const Color light5 = kColor.light(opacity: 0.35);
  static const Color light6 = kColor.light(opacity: 0.45);
  static const Color light7 = kColor.light(opacity: 0.55);
  static const Color light8 = kColor.light(opacity: 0.65);
  static const Color light9 = kColor.light(opacity: 0.85);
  static const Color light0 = kColor.light(opacity: 1.0);

  static Color opa(double d) => kColor.light(opacity: d);

  static Color dopa(double d) => kColor.dark(opacity: d);

  static Color dopacity(double d) =>kColor.dark(opacity: d);

//  @override
//  static Color opacity(double d)=>kColor.light(opacity: d);
}

// ignore: camel_case_types
